# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include kafkaconnect_service.R
NULL

#' Creates a connector using the specified properties
#'
#' @description
#' Creates a connector using the specified properties.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_create_connector/](https://www.paws-r-sdk.com/docs/kafkaconnect_create_connector/) for full documentation.
#'
#' @param capacity &#91;required&#93; Information about the capacity allocated to the connector. Exactly one
#' of the two properties must be specified.
#' @param connectorConfiguration &#91;required&#93; A map of keys to values that represent the configuration for the
#' connector.
#' @param connectorDescription A summary description of the connector.
#' @param connectorName &#91;required&#93; The name of the connector.
#' @param kafkaCluster &#91;required&#93; Specifies which Apache Kafka cluster to connect to.
#' @param kafkaClusterClientAuthentication &#91;required&#93; Details of the client authentication used by the Apache Kafka cluster.
#' @param kafkaClusterEncryptionInTransit &#91;required&#93; Details of encryption in transit to the Apache Kafka cluster.
#' @param kafkaConnectVersion &#91;required&#93; The version of Kafka Connect. It has to be compatible with both the
#' Apache Kafka cluster's version and the plugins.
#' @param logDelivery Details about log delivery.
#' @param plugins &#91;required&#93; Amazon MSK Connect does not currently support specifying multiple
#' plugins as a list. To use more than one plugin for your connector, you
#' can create a single custom plugin using a ZIP file that bundles multiple
#' plugins together.
#' 
#' Specifies which plugin to use for the connector. You must specify a
#' single-element list containing one `customPlugin` object.
#' @param serviceExecutionRoleArn &#91;required&#93; The Amazon Resource Name (ARN) of the IAM role used by the connector to
#' access the Amazon Web Services resources that it needs. The types of
#' resources depends on the logic of the connector. For example, a
#' connector that has Amazon S3 as a destination must have permissions that
#' allow it to write to the S3 destination bucket.
#' @param workerConfiguration Specifies which worker configuration to use with the connector.
#' @param tags The tags you want to attach to the connector.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_create_connector
kafkaconnect_create_connector <- function(capacity, connectorConfiguration, connectorDescription = NULL, connectorName, kafkaCluster, kafkaClusterClientAuthentication, kafkaClusterEncryptionInTransit, kafkaConnectVersion, logDelivery = NULL, plugins, serviceExecutionRoleArn, workerConfiguration = NULL, tags = NULL) {
  op <- new_operation(
    name = "CreateConnector",
    http_method = "POST",
    http_path = "/v1/connectors",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$create_connector_input(capacity = capacity, connectorConfiguration = connectorConfiguration, connectorDescription = connectorDescription, connectorName = connectorName, kafkaCluster = kafkaCluster, kafkaClusterClientAuthentication = kafkaClusterClientAuthentication, kafkaClusterEncryptionInTransit = kafkaClusterEncryptionInTransit, kafkaConnectVersion = kafkaConnectVersion, logDelivery = logDelivery, plugins = plugins, serviceExecutionRoleArn = serviceExecutionRoleArn, workerConfiguration = workerConfiguration, tags = tags)
  output <- .kafkaconnect$create_connector_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$create_connector <- kafkaconnect_create_connector

#' Creates a custom plugin using the specified properties
#'
#' @description
#' Creates a custom plugin using the specified properties.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_create_custom_plugin/](https://www.paws-r-sdk.com/docs/kafkaconnect_create_custom_plugin/) for full documentation.
#'
#' @param contentType &#91;required&#93; The type of the plugin file.
#' @param description A summary description of the custom plugin.
#' @param location &#91;required&#93; Information about the location of a custom plugin.
#' @param name &#91;required&#93; The name of the custom plugin.
#' @param tags The tags you want to attach to the custom plugin.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_create_custom_plugin
kafkaconnect_create_custom_plugin <- function(contentType, description = NULL, location, name, tags = NULL) {
  op <- new_operation(
    name = "CreateCustomPlugin",
    http_method = "POST",
    http_path = "/v1/custom-plugins",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$create_custom_plugin_input(contentType = contentType, description = description, location = location, name = name, tags = tags)
  output <- .kafkaconnect$create_custom_plugin_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$create_custom_plugin <- kafkaconnect_create_custom_plugin

#' Creates a worker configuration using the specified properties
#'
#' @description
#' Creates a worker configuration using the specified properties.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_create_worker_configuration/](https://www.paws-r-sdk.com/docs/kafkaconnect_create_worker_configuration/) for full documentation.
#'
#' @param description A summary description of the worker configuration.
#' @param name &#91;required&#93; The name of the worker configuration.
#' @param propertiesFileContent &#91;required&#93; Base64 encoded contents of connect-distributed.properties file.
#' @param tags The tags you want to attach to the worker configuration.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_create_worker_configuration
kafkaconnect_create_worker_configuration <- function(description = NULL, name, propertiesFileContent, tags = NULL) {
  op <- new_operation(
    name = "CreateWorkerConfiguration",
    http_method = "POST",
    http_path = "/v1/worker-configurations",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$create_worker_configuration_input(description = description, name = name, propertiesFileContent = propertiesFileContent, tags = tags)
  output <- .kafkaconnect$create_worker_configuration_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$create_worker_configuration <- kafkaconnect_create_worker_configuration

#' Deletes the specified connector
#'
#' @description
#' Deletes the specified connector.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_delete_connector/](https://www.paws-r-sdk.com/docs/kafkaconnect_delete_connector/) for full documentation.
#'
#' @param connectorArn &#91;required&#93; The Amazon Resource Name (ARN) of the connector that you want to delete.
#' @param currentVersion The current version of the connector that you want to delete.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_delete_connector
kafkaconnect_delete_connector <- function(connectorArn, currentVersion = NULL) {
  op <- new_operation(
    name = "DeleteConnector",
    http_method = "DELETE",
    http_path = "/v1/connectors/{connectorArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$delete_connector_input(connectorArn = connectorArn, currentVersion = currentVersion)
  output <- .kafkaconnect$delete_connector_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$delete_connector <- kafkaconnect_delete_connector

#' Deletes a custom plugin
#'
#' @description
#' Deletes a custom plugin.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_delete_custom_plugin/](https://www.paws-r-sdk.com/docs/kafkaconnect_delete_custom_plugin/) for full documentation.
#'
#' @param customPluginArn &#91;required&#93; The Amazon Resource Name (ARN) of the custom plugin that you want to
#' delete.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_delete_custom_plugin
kafkaconnect_delete_custom_plugin <- function(customPluginArn) {
  op <- new_operation(
    name = "DeleteCustomPlugin",
    http_method = "DELETE",
    http_path = "/v1/custom-plugins/{customPluginArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$delete_custom_plugin_input(customPluginArn = customPluginArn)
  output <- .kafkaconnect$delete_custom_plugin_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$delete_custom_plugin <- kafkaconnect_delete_custom_plugin

#' Deletes the specified worker configuration
#'
#' @description
#' Deletes the specified worker configuration.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_delete_worker_configuration/](https://www.paws-r-sdk.com/docs/kafkaconnect_delete_worker_configuration/) for full documentation.
#'
#' @param workerConfigurationArn &#91;required&#93; The Amazon Resource Name (ARN) of the worker configuration that you want
#' to delete.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_delete_worker_configuration
kafkaconnect_delete_worker_configuration <- function(workerConfigurationArn) {
  op <- new_operation(
    name = "DeleteWorkerConfiguration",
    http_method = "DELETE",
    http_path = "/v1/worker-configurations/{workerConfigurationArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$delete_worker_configuration_input(workerConfigurationArn = workerConfigurationArn)
  output <- .kafkaconnect$delete_worker_configuration_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$delete_worker_configuration <- kafkaconnect_delete_worker_configuration

#' Returns summary information about the connector
#'
#' @description
#' Returns summary information about the connector.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_describe_connector/](https://www.paws-r-sdk.com/docs/kafkaconnect_describe_connector/) for full documentation.
#'
#' @param connectorArn &#91;required&#93; The Amazon Resource Name (ARN) of the connector that you want to
#' describe.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_describe_connector
kafkaconnect_describe_connector <- function(connectorArn) {
  op <- new_operation(
    name = "DescribeConnector",
    http_method = "GET",
    http_path = "/v1/connectors/{connectorArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$describe_connector_input(connectorArn = connectorArn)
  output <- .kafkaconnect$describe_connector_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$describe_connector <- kafkaconnect_describe_connector

#' Returns information about the specified connector's operations
#'
#' @description
#' Returns information about the specified connector's operations.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_describe_connector_operation/](https://www.paws-r-sdk.com/docs/kafkaconnect_describe_connector_operation/) for full documentation.
#'
#' @param connectorOperationArn &#91;required&#93; ARN of the connector operation to be described.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_describe_connector_operation
kafkaconnect_describe_connector_operation <- function(connectorOperationArn) {
  op <- new_operation(
    name = "DescribeConnectorOperation",
    http_method = "GET",
    http_path = "/v1/connectorOperations/{connectorOperationArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$describe_connector_operation_input(connectorOperationArn = connectorOperationArn)
  output <- .kafkaconnect$describe_connector_operation_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$describe_connector_operation <- kafkaconnect_describe_connector_operation

#' A summary description of the custom plugin
#'
#' @description
#' A summary description of the custom plugin.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_describe_custom_plugin/](https://www.paws-r-sdk.com/docs/kafkaconnect_describe_custom_plugin/) for full documentation.
#'
#' @param customPluginArn &#91;required&#93; Returns information about a custom plugin.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_describe_custom_plugin
kafkaconnect_describe_custom_plugin <- function(customPluginArn) {
  op <- new_operation(
    name = "DescribeCustomPlugin",
    http_method = "GET",
    http_path = "/v1/custom-plugins/{customPluginArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$describe_custom_plugin_input(customPluginArn = customPluginArn)
  output <- .kafkaconnect$describe_custom_plugin_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$describe_custom_plugin <- kafkaconnect_describe_custom_plugin

#' Returns information about a worker configuration
#'
#' @description
#' Returns information about a worker configuration.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_describe_worker_configuration/](https://www.paws-r-sdk.com/docs/kafkaconnect_describe_worker_configuration/) for full documentation.
#'
#' @param workerConfigurationArn &#91;required&#93; The Amazon Resource Name (ARN) of the worker configuration that you want
#' to get information about.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_describe_worker_configuration
kafkaconnect_describe_worker_configuration <- function(workerConfigurationArn) {
  op <- new_operation(
    name = "DescribeWorkerConfiguration",
    http_method = "GET",
    http_path = "/v1/worker-configurations/{workerConfigurationArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$describe_worker_configuration_input(workerConfigurationArn = workerConfigurationArn)
  output <- .kafkaconnect$describe_worker_configuration_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$describe_worker_configuration <- kafkaconnect_describe_worker_configuration

#' Lists information about a connector's operation(s)
#'
#' @description
#' Lists information about a connector's operation(s).
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_list_connector_operations/](https://www.paws-r-sdk.com/docs/kafkaconnect_list_connector_operations/) for full documentation.
#'
#' @param connectorArn &#91;required&#93; The Amazon Resource Name (ARN) of the connector for which to list
#' operations.
#' @param maxResults Maximum number of connector operations to fetch in one get request.
#' @param nextToken If the response is truncated, it includes a NextToken. Send this
#' NextToken in a subsequent request to continue listing from where it left
#' off.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_list_connector_operations
kafkaconnect_list_connector_operations <- function(connectorArn, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListConnectorOperations",
    http_method = "GET",
    http_path = "/v1/connectors/{connectorArn}/operations",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "connectorOperations"),
    stream_api = FALSE
  )
  input <- .kafkaconnect$list_connector_operations_input(connectorArn = connectorArn, maxResults = maxResults, nextToken = nextToken)
  output <- .kafkaconnect$list_connector_operations_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$list_connector_operations <- kafkaconnect_list_connector_operations

#' Returns a list of all the connectors in this account and Region
#'
#' @description
#' Returns a list of all the connectors in this account and Region. The list is limited to connectors whose name starts with the specified prefix. The response also includes a description of each of the listed connectors.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_list_connectors/](https://www.paws-r-sdk.com/docs/kafkaconnect_list_connectors/) for full documentation.
#'
#' @param connectorNamePrefix The name prefix that you want to use to search for and list connectors.
#' @param maxResults The maximum number of connectors to list in one response.
#' @param nextToken If the response of a ListConnectors operation is truncated, it will
#' include a NextToken. Send this NextToken in a subsequent request to
#' continue listing from where the previous operation left off.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_list_connectors
kafkaconnect_list_connectors <- function(connectorNamePrefix = NULL, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListConnectors",
    http_method = "GET",
    http_path = "/v1/connectors",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "connectors"),
    stream_api = FALSE
  )
  input <- .kafkaconnect$list_connectors_input(connectorNamePrefix = connectorNamePrefix, maxResults = maxResults, nextToken = nextToken)
  output <- .kafkaconnect$list_connectors_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$list_connectors <- kafkaconnect_list_connectors

#' Returns a list of all of the custom plugins in this account and Region
#'
#' @description
#' Returns a list of all of the custom plugins in this account and Region.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_list_custom_plugins/](https://www.paws-r-sdk.com/docs/kafkaconnect_list_custom_plugins/) for full documentation.
#'
#' @param maxResults The maximum number of custom plugins to list in one response.
#' @param nextToken If the response of a ListCustomPlugins operation is truncated, it will
#' include a NextToken. Send this NextToken in a subsequent request to
#' continue listing from where the previous operation left off.
#' @param namePrefix Lists custom plugin names that start with the specified text string.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_list_custom_plugins
kafkaconnect_list_custom_plugins <- function(maxResults = NULL, nextToken = NULL, namePrefix = NULL) {
  op <- new_operation(
    name = "ListCustomPlugins",
    http_method = "GET",
    http_path = "/v1/custom-plugins",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "customPlugins"),
    stream_api = FALSE
  )
  input <- .kafkaconnect$list_custom_plugins_input(maxResults = maxResults, nextToken = nextToken, namePrefix = namePrefix)
  output <- .kafkaconnect$list_custom_plugins_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$list_custom_plugins <- kafkaconnect_list_custom_plugins

#' Lists all the tags attached to the specified resource
#'
#' @description
#' Lists all the tags attached to the specified resource.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_list_tags_for_resource/](https://www.paws-r-sdk.com/docs/kafkaconnect_list_tags_for_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource for which you want to
#' list all attached tags.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_list_tags_for_resource
kafkaconnect_list_tags_for_resource <- function(resourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "GET",
    http_path = "/v1/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$list_tags_for_resource_input(resourceArn = resourceArn)
  output <- .kafkaconnect$list_tags_for_resource_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$list_tags_for_resource <- kafkaconnect_list_tags_for_resource

#' Returns a list of all of the worker configurations in this account and
#' Region
#'
#' @description
#' Returns a list of all of the worker configurations in this account and Region.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_list_worker_configurations/](https://www.paws-r-sdk.com/docs/kafkaconnect_list_worker_configurations/) for full documentation.
#'
#' @param maxResults The maximum number of worker configurations to list in one response.
#' @param nextToken If the response of a ListWorkerConfigurations operation is truncated, it
#' will include a NextToken. Send this NextToken in a subsequent request to
#' continue listing from where the previous operation left off.
#' @param namePrefix Lists worker configuration names that start with the specified text
#' string.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_list_worker_configurations
kafkaconnect_list_worker_configurations <- function(maxResults = NULL, nextToken = NULL, namePrefix = NULL) {
  op <- new_operation(
    name = "ListWorkerConfigurations",
    http_method = "GET",
    http_path = "/v1/worker-configurations",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "workerConfigurations"),
    stream_api = FALSE
  )
  input <- .kafkaconnect$list_worker_configurations_input(maxResults = maxResults, nextToken = nextToken, namePrefix = namePrefix)
  output <- .kafkaconnect$list_worker_configurations_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$list_worker_configurations <- kafkaconnect_list_worker_configurations

#' Attaches tags to the specified resource
#'
#' @description
#' Attaches tags to the specified resource.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_tag_resource/](https://www.paws-r-sdk.com/docs/kafkaconnect_tag_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource to which you want to
#' attach tags.
#' @param tags &#91;required&#93; The tags that you want to attach to the resource.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_tag_resource
kafkaconnect_tag_resource <- function(resourceArn, tags) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/v1/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$tag_resource_input(resourceArn = resourceArn, tags = tags)
  output <- .kafkaconnect$tag_resource_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$tag_resource <- kafkaconnect_tag_resource

#' Removes tags from the specified resource
#'
#' @description
#' Removes tags from the specified resource.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_untag_resource/](https://www.paws-r-sdk.com/docs/kafkaconnect_untag_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource from which you want to
#' remove tags.
#' @param tagKeys &#91;required&#93; The keys of the tags that you want to remove from the resource.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_untag_resource
kafkaconnect_untag_resource <- function(resourceArn, tagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "DELETE",
    http_path = "/v1/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$untag_resource_input(resourceArn = resourceArn, tagKeys = tagKeys)
  output <- .kafkaconnect$untag_resource_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$untag_resource <- kafkaconnect_untag_resource

#' Updates the specified connector
#'
#' @description
#' Updates the specified connector.
#'
#' See [https://www.paws-r-sdk.com/docs/kafkaconnect_update_connector/](https://www.paws-r-sdk.com/docs/kafkaconnect_update_connector/) for full documentation.
#'
#' @param capacity The target capacity.
#' @param connectorConfiguration A map of keys to values that represent the configuration for the
#' connector.
#' @param connectorArn &#91;required&#93; The Amazon Resource Name (ARN) of the connector that you want to update.
#' @param currentVersion &#91;required&#93; The current version of the connector that you want to update.
#'
#' @keywords internal
#'
#' @rdname kafkaconnect_update_connector
kafkaconnect_update_connector <- function(capacity = NULL, connectorConfiguration = NULL, connectorArn, currentVersion) {
  op <- new_operation(
    name = "UpdateConnector",
    http_method = "PUT",
    http_path = "/v1/connectors/{connectorArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .kafkaconnect$update_connector_input(capacity = capacity, connectorConfiguration = connectorConfiguration, connectorArn = connectorArn, currentVersion = currentVersion)
  output <- .kafkaconnect$update_connector_output()
  config <- get_config()
  svc <- .kafkaconnect$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.kafkaconnect$operations$update_connector <- kafkaconnect_update_connector
